@@ -4,7 +4,9 @@ const slider = {
       <div class="slider">
         <div class="ui-slider-handle"></div>
       </div>
-    </div>`,
+      <div class="interpret_range"></div>
+    </div>
+    `,
   init: function(opts) {
     let io = this;
     this.minimum = opts.minimum;
@@ -25,8 +27,21 @@ const slider = {
     let value = this.slider.slider("value");
     this.io_master.input(this.id, parseFloat(value));
   },
+  show_interpretation: function(data) {
+    let html = ""
+    for (let [i, value] of data.entries()) {
+      html += `
+        <div class='alternate'
+          alternate_index=${i}
+          style='background-color: ${getSaliencyColor(value)}'>
+        </div>      `
+    }
+    this.target.find(".interpret_range").html(html);
+  },
+  interpretation_logic: "Highlights the result of the alternative values along slider. Hover to see alternative output.",
   clear: function() {
-    this.target.find("input").val(this.default);
+    this.load_example(this.minimum)
+    this.target.find(".interpret_range").empty();
   },
   load_example: function(data) {
     this.target.find(".slider").slider("option", "value", data)
