@@ -22,7 +22,7 @@ const audio_output = {
     })
   },
   output: function(data) {
-    io.target.find(".player").removeClass("hidden");
+    this.target.find(".player").removeClass("hidden");
     this.wavesurfer.load(data);
   },
   clear: function() {
@@ -30,5 +30,8 @@ const audio_output = {
     if (this.wavesurfer) {
       this.wavesurfer.stop();
     }
-  }
+  },
+  load_example_preview: function(data) {
+    return "[audio]";
+  },
 }
